#!/bin/bash

FILE="2.1.xml"

function die {
  echo "ERROR: $@"
  exit 1
}

function check_file {
  [[ -f "$1" ]] || die "FILE '$1' not found"
}

function strip {
  s=$(cat)
  s=${s## }
  echo ${s%% }
}

check_file "$FILE"

xmllint --version 2> /dev/null || die "xmllint not found. Please install it."
xsltproc --version > /dev/null || die "xsltproc not found. Please install it."

xmllint --noout 2.1.xml || die "File '$FILE' is not a valid XML file."

check_file "2.1.test1.xslt"
NUMLINES=$(xsltproc "2.1.test1.xslt" "$FILE" | wc -l | strip) || die "Error in '$FILE'"
[[ "$NUMLINES" = 2 ]] || die "Expecting 2 elements below the root XML element\
 (animaux de la foret + animaux de la savane); found $NUMLINES"
echo "Test 1 PASSED"

check_file "2.1.test2.xslt"
LINES=$(xsltproc "2.1.test2.xslt" "$FILE") || die "Error in '$FILE'"
[[ $(echo "$LINES" | wc -l | strip) = 5 ]] \
  && [[ $(echo "$LINES" | egrep -c '^animal$') = 5 ]] \
  || die "Expecting 5 elements <animal>, all grandchildren of the root, found:
$LINES"
echo "Test 2 PASSED"

check_file "2.1.test3.xslt"
LINES=$(xsltproc "2.1.test3.xslt" "$FILE") || die "Error in '$FILE'"
[[ -z "$LINES" ]] \
  || die "Expected zero element lower than 3 levels below the root; but found:
${LINES}"
echo "Test 3 PASSED"

check_file "2.1.test4.xslt"
LINES=$(xsltproc "2.1.test4.xslt" "$FILE") || die "Error in '$FILE'"
[[ $(echo "$LINES" | wc -l | strip) = 2 ]]\
  && [[ $(echo "$LINES" | egrep -c '^animal$' | strip) = 2 ]] \
  || die "Expecting 2 elements <animal> with attribute 'herbivore', found:
$LINES"
echo "Test 4 PASSED"

check_file "2.1.test5.xslt"
OUTPUT=$(xsltproc "2.1.test5.xslt" "$FILE") || die "Error in '$FILE'"
[[ "$OUTPUT" = "zèbre;herbe" ]] || die "Expected the animal with attribute\
 herbivore='oui' to have a <nom> element with 'zèbre' and a <repas> element\
 with 'herbe'."
echo "Test 5 PASSED"

echo "SUCCESS"
